@@ -278,7 +278,8 @@ class EventFramework(_EventFramework):
         """
         return self.ealloter.update()
 
-    def parallel(self, task: Task, *fn_args, delta=0.5, count=1, **fn_kwgs) -> Worker:
+    @staticmethod
+    def parallel(task: Task, *fn_args, delta=0.5, count=1, **fn_kwgs) -> Worker:
         """
         平行地做某事，用于执行一个task或是callable
         Do something in parallel to execute a task or call
@@ -318,6 +319,9 @@ class EventFramework(_EventFramework):
         return str(self)
 
 
+Parallel = EventFramework.parallel
+
+
 if __name__ == '__main__':
     none = _PARAM_NONE()
     print(none)
