@@ -12,7 +12,7 @@ from abc import ABC, abstractmethod
 from efr.utils.IdGenerator import NewRandomID, NewRandom
 from efr.utils.Functions import EmptyFunction, singleton
 from efr.utils.Trace import Trace
-from efr.utils.Worker import Worker, STOPTASK
+from efr.utils.Worker import Worker, STOPTASK, CIRCLE
 from efr.utils.Task import Task
 
 if __name__ == '__main__':
